package PlayTravel.Activity;

import java.io.IOException;
import java.util.List;

import PlayTravel.Map.MyLocationOverlay;
import android.app.AlertDialog;
import android.app.ProgressDialog;
import android.content.DialogInterface;
import android.content.Intent;
import android.graphics.drawable.Drawable;
import android.location.Address;
import android.location.Criteria;
import android.location.Geocoder;
import android.location.Location;
import android.location.LocationListener;
import android.location.LocationManager;
import android.os.Bundle;
import android.os.Handler;
import android.view.View;
import android.view.View.OnClickListener;
import android.widget.TextView;
import android.widget.Toast;

import com.google.android.maps.GeoPoint;
import com.google.android.maps.MapActivity;
import com.google.android.maps.MapController;
import com.google.android.maps.MapView;
import com.google.android.maps.OverlayItem;

public class MyLocationSetting extends MapActivity implements OnClickListener{
	
    private Location location;
    private double lat;
    private double lng;
    private MapView mapView;
    private AddressSetting mAddress;
    private Geocoder gc;
    private String address_str;
    private String local_name;
    private double sendLat;
    private double sendLng;
    private LocationManager locationManager;
    private boolean gpsState;
    private boolean networkState;
    Handler mHandler;
    private int i;
    private ProgressDialog progress;
	
    @Override
	protected void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);
		setContentView(R.layout.locationsetting);
		mAddress = new AddressSetting();
		gc = new Geocoder(this);
		findViewById(R.id.locationsetting_ok).setOnClickListener(this);
	
		locationManager = (LocationManager) getSystemService(LOCATION_SERVICE);
        
        gpsState = locationManager.isProviderEnabled(LocationManager.GPS_PROVIDER);
        networkState = locationManager.isProviderEnabled(LocationManager.NETWORK_PROVIDER);
        
        i=0;
        mHandler = new Handler();

		if(!gpsState && !networkState){
			createGpsDisabledAlert();
		}
		if(gpsState || networkState){
			Criteria criteria = new Criteria();
			criteria.setAccuracy(Criteria.NO_REQUIREMENT);
			criteria.setPowerRequirement(Criteria.NO_REQUIREMENT);
			String provider = locationManager.getBestProvider(criteria, true);
			location = locationManager.getLastKnownLocation(provider);
			locationManager.requestLocationUpdates(provider, 10000, 0, locationListener);
			
			progress = ProgressDialog.show(MyLocationSetting.this, "", "Loading...");
			mHandler.post(mTimeRunnable);
		}
	}
    
 // GPS Disabled Alert
	private void createGpsDisabledAlert() {
	    AlertDialog.Builder builder = new AlertDialog.Builder(this);
	    builder.setMessage(" ġ ľϷ Ʈũ GPS ʿմϴ.  ̵Ͻðڽϱ? ")
	            .setCancelable(false)
	            .setPositiveButton("Ȯ",
	                    new DialogInterface.OnClickListener() {
	                        public void onClick(DialogInterface dialog, int id) {
	                            showGpsOptions();
	                        }
	                        
	                })
	            .setNegativeButton("",
	                    new DialogInterface.OnClickListener() {
	                        public void onClick(DialogInterface dialog, int id) {
	                            dialog.cancel();
	                            if(!gpsState && !networkState){
	                        		finish();
	                        	}
	                        }
	                });
	    AlertDialog alert = builder.create();
	    alert.show();
	}
	
	// show GPS Options
	private void showGpsOptions() {
	    Intent gpsOptionsIntent = new Intent(android.provider.Settings.ACTION_LOCATION_SOURCE_SETTINGS);
	    startActivity(gpsOptionsIntent);
	    finish();
	}
	
	Runnable mTimeRunnable = new Runnable() {
    	public void run(){
    		if(++i > 10){
    			updateWithNewLocation(location);
    			Toast.makeText(MyLocationSetting.this, "GPS Ǵ Ʈũȣ մϴ.  ġ ã Ŭּ", Toast.LENGTH_LONG).show();
    			if(!gpsState || !networkState){
    				createGpsDisabledAlert();
    			}
    		}else{
    			mHandler.postDelayed(this, 1000);
    		}
    	}
    };

	@Override
	protected void onStop() {
		locationManager.removeUpdates(locationListener);
		super.onStop();
	}

	@Override
	public void onClick(View v) {
		switch(v.getId())
		{
		case R.id.locationsetting_ok:
			Intent intent = getIntent();
			intent.putExtra("address", address_str);
			intent.putExtra("x", sendLat);
			intent.putExtra("y", sendLng);
			intent.putExtra("local", local_name); //̸
			setResult(RESULT_OK,intent);
			finish();
			break;
		}
	}

	private final LocationListener locationListener = new LocationListener() {
		
		@Override
		public void onStatusChanged(String provider, int status, Bundle extras) {
		}
		
		@Override
		public void onProviderEnabled(String provider) {
		}
		
		@Override
		public void onProviderDisabled(String provider) {
			updateWithNewLocation(null);
		}
		
		@Override
		public void onLocationChanged(Location location) {
			updateWithNewLocation(location);
		}
	};
	
	private double[] updateWithNewLocation(Location location)
	{
		progress.dismiss();
    	mHandler.removeCallbacks(mTimeRunnable);
    	locationManager.removeUpdates(locationListener);
    	
		double[] loca = new double[2];
		if(location !=null)
		{
			lat = location.getLatitude();
			lng = location.getLongitude();
			loca[0] = lat;
			loca[1] = lng;
		}
		else
		{	
			loca[0] = 37.466044;
			loca[1] = 126.959804;
		}
		
		mapView = (MapView) findViewById(R.id.mapview);
		mapView.setBuiltInZoomControls(true);  
	    MapController mc=mapView.getController();
	        
		Drawable drawable = this.getResources().getDrawable(R.drawable.icon_me); 
		MyLocationOverlay itemizedoverlay = new MyLocationOverlay(this, drawable, mAddress);
       
        GeoPoint point = new GeoPoint((int)(loca[0]*1E6),(int)(loca[1]*1E6));
        
        OverlayItem item = new OverlayItem(point, "", "");
        item.setMarker(drawable);
        itemizedoverlay.addOverlay(item, drawable);
        mapView.getOverlays().add(itemizedoverlay); 
       
        mc.animateTo(point);
        mc.setZoom(18);
        
        try {
			mAddress.setAddress(loca[0], loca[1]);
		} catch (IOException e) {
			e.printStackTrace();
		}
		
		return loca;
	}
	
	
	@Override
	protected boolean isRouteDisplayed() {
		// TODO Auto-generated method stub
		return false;
	}
	
	//ּҷ ȯ
	public class AddressSetting{
		TextView addressView= (TextView)findViewById(R.id.address);
		
		public void setAddress(double lat, double lng) throws IOException{
			try{
				List<Address> address = gc.getFromLocation(lat, lng, 1);
				address_str = address.get(0).getAddressLine(0);
				addressView.setText(address_str);
				sendLat = lat;
				sendLng = lng;
				local_name = address.get(0).getLocality();
			}catch(Exception e){
				e.printStackTrace();
			}
		}
	}

}
