package PlayTravel.Map;

import java.util.ArrayList;

import PlayTravel.Activity.AlbumMapView.MapDescription;
import PlayTravel.Data.WayPoint;
import android.content.Context;
import android.graphics.Bitmap;
import android.graphics.Canvas;
import android.graphics.Paint;
import android.graphics.Path;
import android.graphics.PathDashPathEffect;
import android.graphics.Point;
import android.graphics.drawable.Drawable;
import android.util.Log;
import android.widget.Toast;

import com.google.android.maps.GeoPoint;
import com.google.android.maps.ItemizedOverlay;
import com.google.android.maps.MapController;
import com.google.android.maps.MapView;
import com.google.android.maps.OverlayItem;
import com.google.android.maps.Projection;

public class MapViewOverlay extends ItemizedOverlay<OverlayItem> {
	private ArrayList<OverlayItem> mOverlays = new ArrayList<OverlayItem>();
	private MapDescription mDescription;
	private Context mContext;
	private ArrayList<WayPoint> list;
	private int beforeIndex;
	private MapController mc;
	private Paint mPaint;
 
 public MapViewOverlay(Context context, Drawable marker, ArrayList<WayPoint> list, MapDescription description, MapController mc) {
  super(marker);
  mContext = context;
  mDescription = description; 
  this.list = list;
  beforeIndex = 0;
  this.mc = mc;
  
mPaint = new Paint();
mPaint.setAntiAlias(true);
mPaint.setColor(0xff3c2900);
mPaint.setStyle(Paint.Style.STROKE);
mPaint.setStrokeJoin(Paint.Join.ROUND);
mPaint.setStrokeCap(Paint.Cap.ROUND);
mPaint.setStrokeWidth(4.0f);
mPaint.setDither(true);
mPaint.setPathEffect(new PathDashPathEffect(makePathDash(), 18, 3.0f,PathDashPathEffect.Style.ROTATE));



 }

@Override
public void draw(Canvas canvas, MapView mapView, boolean shadow) {
	GeoPoint geopoint;
	Point point = new Point();
	Projection projection = mapView.getProjection();

	Canvas mCanvas = new Canvas();
	Bitmap mBitmap = Bitmap.createBitmap(mapView.getWidth(), mapView.getHeight(), Bitmap.Config.ARGB_8888);
	mCanvas.setBitmap(mBitmap);
	Path mPath = new Path();
	 
	 for(int i=0; i<mOverlays.size()-1; i++){
		 Point tmpPoint = new Point();
		 Log.d("line",i + "==" + point.x + "==" + point.y);
		 geopoint = mOverlays.get(i).getPoint(); 
		 projection.toPixels(geopoint, point);
		 
		 Integer tmpX = point.x;
		 Integer tmpY = point.y;
		 geopoint = mOverlays.get(i+1).getPoint(); 
		 projection.toPixels(geopoint, tmpPoint);
		 
		 if (tmpX != tmpPoint.x && tmpY != tmpPoint.y)
		 {
			 mPath.moveTo(point.x, point.y-10);
			 geopoint = mOverlays.get(i+1).getPoint(); 
			 projection.toPixels(geopoint, point);		 
			 mPath.lineTo(point.x, point.y-10);				 
		 }
		 canvas.drawPath(mPath, mPaint);
	 }
	 
	super.draw(canvas, mapView, shadow);
}

private static Path makePathDash() {
    Path p = new Path();
    p.moveTo(4, 0);
    p.lineTo(0, -4);
    p.lineTo(8, -4);
    p.lineTo(12, 0);
    p.lineTo(8, 4);
    p.lineTo(0, 4);
    return p;
}

@Override
 protected OverlayItem createItem(int i) {
  return mOverlays.get(i); 
 }

@Override
 public int size() {
  return  mOverlays.size();
 }
 
 public void addOverlay(OverlayItem overlay, Drawable marker) { 
     mOverlays.add(overlay); 
     boundCenterBottom(marker);
     populate(); 
 }
 
 public void onPrev(){
	 if(beforeIndex == 0){
			Toast.makeText(mContext, "ù° ڽԴϴ", Toast.LENGTH_SHORT).show();
	}
	else{
		OverlayItem item = mOverlays.get(beforeIndex-1);
		 OverlayItem beforeItem = mOverlays.get(beforeIndex);
		 Marker res = new Marker();
		 Drawable marker = null;
		 
		 // Ŀ  ٽ ٲ
		 marker = mContext.getResources().getDrawable(res.getId(0, list.get(beforeIndex).getCategoryID()));
		 marker.setBounds(0, 0, marker.getIntrinsicWidth(), marker.getIntrinsicHeight());
		 beforeItem.setMarker(marker);
		 boundCenterBottom(marker);
		 populate();
		 //Ŭ Ŀ ũ
		 marker = mContext.getResources().getDrawable(res.getId(1, list.get(beforeIndex-1).getCategoryID()));
		 marker.setBounds(0, 0, marker.getIntrinsicWidth(), marker.getIntrinsicHeight());
		 item.setMarker(marker);
		 boundCenterBottom(marker);
		 populate();
		 
		 beforeIndex = beforeIndex-1;
		 
		 GeoPoint point = new GeoPoint((int)(list.get(beforeIndex).getX()*1E6), (int)(list.get(beforeIndex).getY()*1E6));
		 mc.animateTo(point);
		
		 mDescription.setDescription(beforeIndex);
		 
//		 if(markerFlag == true){
//			 mDescription.refresh();
//			 mDescription.setDescription(beforeIndex);
//		 }
//		 else{
//			 mDescription.refresh();
//		 }
	} 
 }
 
 public void onNext(){
	 if(beforeIndex == mOverlays.size()-1){
		Toast.makeText(mContext, " ڽԴϴ", Toast.LENGTH_SHORT).show();
	 }
	 else{
		 OverlayItem item = mOverlays.get(beforeIndex+1);
		 OverlayItem beforeItem = mOverlays.get(beforeIndex);
		 Marker res = new Marker();
		 Drawable marker = null;
		 
		 // Ŀ  ٽ ٲ
		 marker = mContext.getResources().getDrawable(res.getId(0, list.get(beforeIndex).getCategoryID()));
		 marker.setBounds(0, 0, marker.getIntrinsicWidth(), marker.getIntrinsicHeight());
		 beforeItem.setMarker(marker);
		 boundCenterBottom(marker);
		 populate();
		 //Ŭ Ŀ ũ
		 marker = mContext.getResources().getDrawable(res.getId(1, list.get(beforeIndex+1).getCategoryID()));
		 marker.setBounds(0, 0, marker.getIntrinsicWidth(), marker.getIntrinsicHeight());
		 item.setMarker(marker);
		 boundCenterBottom(marker);
		 populate();
		 
		 beforeIndex = beforeIndex+1;
		 GeoPoint point = new GeoPoint((int)(list.get(beforeIndex).getX()*1E6), (int)(list.get(beforeIndex).getY()*1E6));
		 mc.animateTo(point);
		 
		 mDescription.setDescription(beforeIndex);
		 
//		 if(markerFlag == true){
//			 mDescription.refresh();
//			 mDescription.setDescription(beforeIndex);
//		 }
//		 else{
//			 mDescription.refresh();
//		 }
	 }
 }

@Override 
 protected boolean onTap(int index) { 
	
	 if(beforeIndex != index){  //  Ŀ Ŭ  ƹ 
		 OverlayItem item = mOverlays.get(index);
		 OverlayItem beforeItem = mOverlays.get(beforeIndex);
		 Marker res = new Marker();
		 Drawable marker = null;
		 
		mDescription.setDescription(index);
			 
		// Ŀ  ٽ ٲ
		 marker = mContext.getResources().getDrawable(res.getId(0, list.get(beforeIndex).getCategoryID()));
		 marker.setBounds(0, 0, marker.getIntrinsicWidth(), marker.getIntrinsicHeight());
		 beforeItem.setMarker(marker);
		 boundCenterBottom(marker);
		 
		 //Ŭ Ŀ ũ
		 marker = mContext.getResources().getDrawable(res.getId(1, list.get(index).getCategoryID()));
		 marker.setBounds(0, 0, marker.getIntrinsicWidth(), marker.getIntrinsicHeight());
		 item.setMarker(marker);
		 boundCenterBottom(marker);

		 beforeIndex = index;
	 }
	 else{
		 mDescription.setVisible();
	 }
   return true; 
 }

}